@@ -1,4 +1,4 @@
-/* $Id: texcyl.c,v 1.2 1999/10/21 16:39:06 brianp Exp $ */
+/* $Id: texcyl.c,v 1.5 2001/03/27 17:35:26 brianp Exp $ */
 
 /*
  * Textured cylinder demo: lighting, texturing, reflection mapping.
@@ -12,6 +12,38 @@
 
 /*
  * $Log: texcyl.c,v $
+ * Revision 1.5  2001/03/27 17:35:26  brianp
+ * set initial window pos
+ *
+ * Revision 1.4  2000/12/24 22:53:54  pesco
+ * * demos/Makefile.am (INCLUDES): Added -I$(top_srcdir)/util.
+ * * demos/Makefile.X11, demos/Makefile.BeOS-R4, demos/Makefile.cygnus:
+ * Essentially the same.
+ * Program files updated to include "readtex.c", not "../util/readtex.c".
+ * * demos/reflect.c: Likewise for "showbuffer.c".
+ *
+ *
+ * * Makefile.am (EXTRA_DIST): Added top-level regular files.
+ *
+ * * include/GL/Makefile.am (INC_X11): Added glxext.h.
+ *
+ *
+ * * src/GGI/include/ggi/mesa/Makefile.am (EXTRA_HEADERS): Include
+ * Mesa GGI headers in dist even if HAVE_GGI is not given.
+ *
+ * * configure.in: Look for GLUT and demo source dirs in $srcdir.
+ *
+ * * src/swrast/Makefile.am (libMesaSwrast_la_SOURCES): Set to *.[ch].
+ * More source list updates in various Makefile.am's.
+ *
+ * * Makefile.am (dist-hook): Remove CVS directory from distribution.
+ * (DIST_SUBDIRS): List all possible subdirs here.
+ * (SUBDIRS): Only list subdirs selected for build again.
+ * The above two applied to all subdir Makefile.am's also.
+ *
+ * Revision 1.3  2000/09/29 23:09:39  brianp
+ * added fps output
+ *
  * Revision 1.2  1999/10/21 16:39:06  brianp
  * added -info command line option
  *
@@ -38,7 +70,7 @@
 #include <math.h>
 #include <GL/glut.h>
 
-#include "../util/readtex.c"   /* I know, this is a hack. */
+#include "readtex.c"   /* I know, this is a hack. */
 
 #define TEXTURE_FILE "../images/reflect.rgb"
 
@@ -56,6 +88,10 @@ static GLboolean Animate = GL_TRUE;
 static GLfloat Xrot = 0.0, Yrot = 0.0, Zrot = 0.0;
 static GLfloat DXrot = 1.0, DYrot = 2.5;
 
+/* performance info */
+static GLint T0 = 0;
+static GLint Frames = 0;
+
 
 static void Idle( void )
 {
@@ -81,6 +117,18 @@ static void Display( void )
    glPopMatrix();
 
    glutSwapBuffers();
+
+   if (Animate) {
+      GLint t = glutGet(GLUT_ELAPSED_TIME);
+      Frames++;
+      if (t - T0 >= 5000) {
+         GLfloat seconds = (t - T0) / 1000.0;
+         GLfloat fps = Frames / seconds;
+         printf("%d frames in %g seconds = %g FPS\n", Frames, seconds, fps);
+         T0 = t;
+         Frames = 0;
+      }
+   }
 }
 
 
@@ -248,6 +296,7 @@ int main( int argc, char *argv[] )
 {
    glutInit( &argc, argv );
    glutInitWindowSize( 400, 400 );
+   glutInitWindowPosition( 0, 0 );
 
    glutInitDisplayMode( GLUT_RGB | GLUT_DOUBLE );
 
